// Copyright (c) Caliper Corporation 2003.  All Rights Reserved
// Written by Phil Villars - Caliper Corporation - 2003

    // The toolbox illustrates how to use toolboxes, interface tools, and functions:
    // 1. Demonstration of GISDK "Toolboxes"
    // 2. Demonstration of "User Interface Tools" (ClickCoord(), ClickScope(), etc.)
    // 3. Demonstration of the "ZoomAndCenterMap()" function.
 
    // To run this toolbox using the GISDK toolbox:
    // 1. Open or choose the map that you want to use.
    // 2. Choose Tools-Add-Ins and open the GIS Developer's Kit toolbox.
    // 3. Compile this toolbox in test mode using the first button (Compile).
    // 4. Run this toolbox by clicking the second button (Test), typing the dbox 
    //    name "Zoom Toolbox", clicking the Dialog box radio button, and clicking OK.
    
    // This brings up the toolbox defined in this resource file, it has two
    // buttons, "Zoom In" and "Zoom Out", clicking on one of the buttons
    // "selects" the appropriate tool, then simply click on the map to affect
    // the appropriate action.
    //
    // The user can experiment with setting different values for the zoom factor
    // by altering the "factor" definition in the "Init" item of the toolbox

DBox "Zoom Toolbox" ,,14,7 Toolbox Nokeyboard

    // Initialize
    Init do
        // Set zoom factor variable
        factor = 2.0
    endItem

    // On close terminate the execution of the dialog box and close its window
    Close do Return() endItem

    // Zoom in tool
    Tool "Zoom In" 2, 1, 10, 1.5
    do
        // Awaits user input from the system pointer and returns a scope.
        zoom_scope = ClickScope()
        // Check to see if the clicked rectangle has sufficient
        // width to be considered a rectangle
        map_scope = GetMapScope()
        if zoom_scope.width < 0.001 * map_scope.width then too_narrow = "True"
        if zoom_scope.height < 0.001 * map_scope.height then too_short = "True"

        if (too_narrow OR too_short) then do
           // Zoom to center of the scope
           ZoomAndCenterMap(,1/factor, zoom_scope.center)
           end
        else do
           // Zoom to the new scope
           SetMapScope(, zoom_scope)
           end

        RedrawMap()
     endItem

    // Zoom out tool
    Tool "Zoom Out" 2, 4, 10, 1.5
    do
        zoom_crd = ClickCoord()
        ZoomAndCenterMap(, factor, zoom_crd)
        RedrawMap()
    endItem

endDBox